@@ -10,7 +10,13 @@ class Form802(Form8x):
         _code_dir = f'{os.path.join(src_dir, self.header["uuid"])}.0'
         if os.path.isdir(_code_dir):
             self.form = helper.json_read(_code_dir, 'form.json')
-            self.code['obj'] = helper.txt_read(_code_dir, 'module.txt')
+            try:
+                self.code['obj'] = self.read_raw_code(_code_dir, 'module.txt')
+                encoding = helper.detect_by_bom(os.path.join(_code_dir, 'module.txt'), 'utf-8')
+            except UnicodeDecodeError:
+                encoding = 'windows-1251'
+                self.code['obj'] = self.read_raw_code(_code_dir, 'module.txt', encoding=encoding)
+            self.header['code_encoding_obj'] = encoding  # можно безболезненно поменять на utf-8-sig
             self.header[f'code_info_obj'] = 1
 
     def decode_data(self, src_dir, uuid):
@@ -22,7 +28,8 @@ class Form802(Form8x):
             _code_dir = f'{os.path.join(dest_dir, self.header["uuid"])}.0'
             os.makedirs(_code_dir, exist_ok=True)
             helper.json_write(self.form, _code_dir, 'form.json')
-            helper.txt_write(self.code['obj'], _code_dir, 'module.txt')
+            _encoding = self.header.get('code_encoding_obj', 'utf-8-sig')
+            self.write_raw_code(self.code['obj'], _code_dir, 'module.txt', encoding=_encoding)
 
     def encode_header(self):
         return [[
@@ -950,3 +957,4 @@ class Form802(Form8x):
 
     def encode_data(self):
         pass
+
