@@ -93,7 +93,7 @@ class CodeOrganizer:
         if size_tmp == 0:
             raise Exception(f'{path} {file_name} в include не указан путь')
         _file_name = f'{tmp[-1]}.1c'
-        _path = '..'  # include не должен лежать внутри папки с сиходниками
+        _path = '..'  # include не должен лежать внутри папки с исходниками
         if size_tmp > 1:
             tmp = ['..' if elem == '' else elem for elem in tmp[:-1]]
             _path = os.path.join(_path, *tmp)
