@@ -1,19 +1,11 @@
 # -*- coding: utf-8 -*-
 import datetime
-import io
 import os
+import io
 import tempfile
 import zlib
-from base64 import b64encode
-from hashlib import sha1
 from struct import pack, calcsize
 
-from . import helper
-from .json_container_decoder import JsonContainerDecoder
-from datetime import datetime, timedelta
-from tqdm.auto import tqdm
-
-
 # INT32_MAX
 END_MARKER = 2147483647
 DEFAULT_BLOCK_SIZE = 512  # 0x200
@@ -35,7 +27,7 @@ def epoch2int(epoch_time):
     """
     # Начало эпохи на разных системах - разная дата
     # Поэтому явно вычисляем разницу между указанной датой и 0001.01.01
-    return (datetime.fromtimestamp(epoch_time) - datetime(1, 1, 1)) // timedelta(
+    return (datetime.datetime.fromtimestamp(epoch_time) - datetime.datetime(1, 1, 1)) // datetime.timedelta(
         microseconds=100)
 
 
@@ -74,7 +66,6 @@ class ContainerWriter(object):
     :param file: объект файла контейнера
     :type file: BufferedReader
     """
-
     def __init__(self, file):
         self.file = file
         self.toc = []
@@ -110,20 +101,16 @@ class ContainerWriter(object):
         header = pack('2s8ss8ss8s3s', *[x.encode() for x in header_data])
 
         self.file.write(header)
-        self.write_block_data(self, data, self.file)
-
-        self.file.write(b'\x00' * (block_size - data.tell()))
-
-        return offset
-
-    @staticmethod
-    def write_block_data(container, data, dest_file):
         data.seek(0)
         while True:
             buffer = data.read(BUFFER_CHUNK_SIZE)
             if not buffer:
                 break
-            dest_file.write(buffer)
+            self.file.write(buffer)
+
+        self.file.write(b'\x00' * (block_size - data.tell()))
+
+        return offset
 
     def add_file(self, fd, name, inflate=False):
         """
@@ -144,26 +131,21 @@ class ContainerWriter(object):
         attribute_doc_offset = self.write_block(io.BytesIO(buffer), block_size=len(buffer))
 
         if inflate:
-            data_doc_offset = self.compress(self, fd, self.file, self.write_block)
+            with tempfile.TemporaryFile() as f:
+                compressor = zlib.compressobj(wbits=-15)
+                fd.seek(0)
+                while True:
+                    chunk = fd.read(BUFFER_CHUNK_SIZE)
+                    if not chunk:
+                        f.write(compressor.flush())
+                        break
+                    f.write(compressor.compress(chunk))
+                data_doc_offset = self.write_block(f)
         else:
             data_doc_offset = self.write_block(fd)
 
         self.toc.append((attribute_doc_offset, data_doc_offset))
 
-    @staticmethod
-    def compress(container, src_fd, dest_fd, block_writer):
-        with tempfile.TemporaryFile() as f:
-            compressor = zlib.compressobj(wbits=-15)
-            src_fd.seek(0)
-            while True:
-                chunk = src_fd.read(BUFFER_CHUNK_SIZE)
-                if not chunk:
-                    f.write(compressor.flush())
-                    break
-                f.write(compressor.compress(chunk))
-            data_doc_offset = block_writer(container, f, dest_fd)
-        return data_doc_offset
-
     def write_toc(self):
         """
         Записывает оглавление контейнера
@@ -230,7 +212,7 @@ def add_entries(container, folder, nested=False):
                 container.add_file(entry_file, entry, inflate=not nested)
 
 
-def build(folder, filename, nested=False):
+def build(folder, filename):
     """
     Запаковывает каталог в контейнер включая вложенные каталоги.
     Сахар для ContainerWriter.
@@ -240,68 +222,6 @@ def build(folder, filename, nested=False):
     :param filename: имя файла контейнера
     :type filename: string
     """
-    begin = datetime.now()
-    print(f'{"Запаковываем бинарник":30}:', end="")
-    os.makedirs(os.path.dirname(filename), exist_ok=True)
     with open(filename, 'w+b') as f, ContainerWriter(f) as container:
-        add_entries(container, folder, nested)
-    print(f" - {datetime.now() - begin}")
+        add_entries(container, folder)
 
-
-def calc_sha1(src_folder, dest_folder):
-    entries = sorted(os.listdir(dest_folder))
-    versions = []
-    versions_file = ''
-    for filename in entries:
-        dest_path = os.path.join(dest_folder, filename)
-        if filename == 'configinfo':
-            versions_file = 'configinfo'
-            continue
-
-        with open(dest_path, 'rb') as file:
-            data = file.read()
-        versions.append(f'"{filename}"')
-        versions.append(b64encode(sha1(data).digest()).decode())
-    if not versions_file:
-        return
-    versions.insert(0, str(int(len(versions) / 2)))
-    _versions = JsonContainerDecoder().encode_root_object([versions])
-
-    src_path = os.path.join(src_folder, versions_file)
-    dest_path = os.path.join(dest_folder, versions_file)
-
-    with open(src_path, 'r+', encoding='utf-8') as file:
-        data = file.read()
-        data = data.replace('{____versions____}', _versions)
-        file.seek(0)
-        file.write(data)
-
-    compress_and_build_simple_file(src_path, dest_path)
-    pass
-
-
-def compress_and_build_simple_file(src_path, dest_path):
-    with open(dest_path, 'w+b') as dest_fd:
-        with open(src_path, 'rb') as src_fd:
-            ContainerWriter.compress(None, src_fd, dest_fd, ContainerWriter.write_block_data)
-
-
-def compress_and_build(src_folder, dest_folder, *, pool=None, nested=False):
-    helper.clear_dir(dest_folder)
-    entries = sorted(os.listdir(src_folder))
-
-    with tqdm(desc=f'{"Архивируем контейнеры":30}', total=len(entries)) as pbar:
-        for filename in entries:
-            src_path = os.path.join(src_folder, filename)
-            dest_path = os.path.join(dest_folder, filename)
-            # add_entry(container, src_folder, filename)
-            if os.path.isdir(src_path):
-                with open(dest_path, 'w+b') as dest_fd:
-                    with tempfile.TemporaryFile() as tmp:
-                        with ContainerWriter(tmp) as nested_container:
-                            add_entries(nested_container, src_path, nested=True)
-                        ContainerWriter.compress(None, tmp, dest_fd, ContainerWriter.write_block_data)
-            else:
-                compress_and_build_simple_file(src_path, dest_path)
-            pbar.update()
-        calc_sha1(src_folder, dest_folder)
